:mod:`bloomfilter` --- A NEO specific bloomfilter implementation
================================================================

While ready to install 3rd party bloom filter implementations exist on PyPi, they unfortunately do not comply with the NEO implementation.

Bloomfilter's can be broadcasted over the network and thus there is a need to have identical results.


.. automodule:: neo3.core.cryptography.bloomfilter
   :members:
   :undoc-members:
   :show-inheritance:
   